pub struct HFsInfo(/* private fields */);Expand description
Information about every hard-fork Monero has had.
Implementations
Sourceimpl HFsInfo
impl HFsInfo
pub const fn info_for_hf(&self, hf: &HardFork) -> HFInfo
pub const fn new(hfs: [HFInfo; 16]) -> Self
Sourcepub const fn hard_fork_state(&self, current_time: u64) -> HardForkState
pub const fn hard_fork_state(&self, current_time: u64) -> HardForkState
Returns the hard-fork state based on the current time.
Mirrors HardFork::get_state() in monerod:
HardForkState::LikelyForked: more than one year past the last scheduled fork time.HardForkState::UpdateNeeded: more than six months past the last scheduled fork time.HardForkState::Ready: within six months of the last scheduled fork time.
Sourcepub const fn main_net() -> Self
pub const fn main_net() -> Self
Returns the main-net hard-fork information.
ref: https://monero-book.cuprate.org/consensus_rules/hardforks.html#Mainnet-Hard-Forks
Sourcepub const fn test_net() -> Self
pub const fn test_net() -> Self
Returns the test-net hard-fork information.
ref: https://monero-book.cuprate.org/consensus_rules/hardforks.html#Testnet-Hard-Forks
Sourcepub const fn fake_chain() -> Self
pub const fn fake_chain() -> Self
Returns the fake-chain (regtest) hard-fork information.
Sourcepub const fn stage_net() -> Self
pub const fn stage_net() -> Self
Returns the stagenet hard-fork information.
ref: https://monero-book.cuprate.org/consensus_rules/hardforks.html#Stagenet-Hard-Forks