pub struct HFVotes { /* private fields */ }Expand description
A struct holding the current voting state of the blockchain.
Implementations
Sourceimpl HFVotes
impl HFVotes
pub fn new(window_size: usize) -> Self
Sourcepub fn add_vote_for_hf(&mut self, hf: &HardFork)
pub fn add_vote_for_hf(&mut self, hf: &HardFork)
Add a vote for a hard-fork, this function removes votes outside of the window.
Sourcepub fn reverse_blocks(&mut self, numb_blocks: usize, old_block_votes: Self)
pub fn reverse_blocks(&mut self, numb_blocks: usize, old_block_votes: Self)
Pop a number of blocks from the top of the cache and push some values into the front of the cache, i.e. the oldest blocks.
old_block_votes should contain the HFs below the window that now will be in the window after popping
blocks from the top.
Panics
This will panic if old_block_votes contains more HFs than numb_blocks.
Sourcepub fn votes_for_hf(&self, hf: &HardFork) -> usize
pub fn votes_for_hf(&self, hf: &HardFork) -> usize
Returns the total votes for a hard-fork.
ref: https://monero-book.cuprate.org/consensus_rules/hardforks.html#accepting-a-fork
Sourcepub fn total_votes(&self) -> usize
pub fn total_votes(&self) -> usize
Returns the total amount of votes being tracked
Sourcepub fn current_fork(
&self,
current_hf: &HardFork,
current_height: usize,
window: usize,
hfs_info: &HFsInfo,
) -> HardFork
pub fn current_fork( &self, current_hf: &HardFork, current_height: usize, window: usize, hfs_info: &HFsInfo, ) -> HardFork
Checks if a future hard fork should be activated, returning the next hard-fork that should be activated.
ref: https://monero-book.cuprate.org/consensus_rules/hardforks.html#accepting-a-fork